import { getInfo, login, logout } from '@/api/login';
import { getToken, removeToken, setToken } from '@/utils/auth';
// import { Watermark } from '@pansy/watermark';

// let watermark = null;

const user = {
  state: {
    token: getToken(),
    id: '',
    name: '',
    nickName: '',
    avatar: '',
    roles: [],
    permissions: [],
    deptId: null,
    userType: null,
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_ID: (state, id) => {
      state.id = id
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions
    },
    SET_DEPT_ID: (state, deptId) => {
      state.deptId = deptId;
    },
    SET_NICK_NAME: (state, nickName) => {
      state.nickName = nickName;
      
      // if (watermark) {
      //   watermark.destroy();
      // }
      // // 创建水印
      // watermark = new Watermark({
      //   // 水印文案，支持多行
      //   text: nickName,
      //   // 水印文案样式
      //   font: {
      //     fontSize: 16,
      //     color: 'rgba(0, 0, 0)',
      //     fontFamily: 'sans-serif'
      //   },
      //   // 水印之间的间距
      //   gap: [300, 300],
      //   // 旋转角度
      //   rotate: -20,
      //   // 设置水印层级
      //   zIndex: 9999,
      //   opacity: 0.1,
      // })
    },
    SET_USER_TYPE: (state, userType) => {
      state.userType = userType;
    }
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      const username = userInfo.username.trim()
      const password = userInfo.password
      const code = userInfo.code
      const uuid = userInfo.uuid
      return new Promise((resolve, reject) => {
        login(username, password, code, uuid).then(res => {
          setToken(res.token)
          commit('SET_TOKEN', res.token)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo().then(res => {
          const user = res.user
          const avatar = (user.avatar == "" || user.avatar == null) ? require("@/assets/images/profile.jpg") : process.env.VUE_APP_BASE_API + user.avatar;
          if (res.roles && res.roles.length > 0) { // 验证返回的roles是否是一个非空数组
            commit('SET_ROLES', res.roles)
            commit('SET_PERMISSIONS', res.permissions)
          } else {
            commit('SET_ROLES', ['ROLE_DEFAULT'])
          }
          commit('SET_ID', user.userId)
          commit('SET_NAME', user.userName)
          commit('SET_NICK_NAME', user.nickName)
          commit('SET_AVATAR', avatar)
          commit('SET_DEPT_ID', user.deptId)
          commit('SET_USER_TYPE', user.userType)
          resolve(res)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 退出系统
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          commit('SET_TOKEN', '')
          commit('SET_ROLES', [])
          commit('SET_PERMISSIONS', [])
          removeToken()
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '')
        removeToken()
        resolve()
      })
    }
  }
}

export default user
